@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
-'''
+"""
 This module implements abstract base classes for file io classes.  For seamless
 integration with the rest of the code base, any classes providing to a file io
 function should extend this class.
-'''
+"""
 
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2011, The Materials Project"
@@ -17,17 +17,6 @@ __date__ = "$Sep 23, 2011M$"
 import abc
 
 
-class VaspInput(object):
-    __metaclass__ = abc.ABCMeta
-
-    @abc.abstractmethod
-    def write_file(self, filename):
-        '''
-        Writes the contents to a file.
-        '''
-        return
-
-
 class FeffInput(object):
     __metaclass__ = abc.ABCMeta
 
